@@ -21,14 +21,14 @@ def make_twitter_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
 ):
     """
     Make a blueprint for authenticating with Twitter using OAuth 1. This requires
     an API key and API secret from Twitter. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables TWITTER_OAUTH_API_KEY and TWITTER_OAUTH_API_SECRET.
+    them, using the variables :envvar:`TWITTER_OAUTH_CLIENT_KEY` and
+    :envvar:`TWITTER_OAUTH_CLIENT_SECRET`.
 
     Args:
         api_key (str): The API key for your Twitter application
@@ -66,11 +66,10 @@ def make_twitter_blueprint(
         login_url=login_url,
         authorized_url=authorized_url,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
-    twitter_bp.from_config["client_key"] = "TWITTER_OAUTH_API_KEY"
-    twitter_bp.from_config["client_secret"] = "TWITTER_OAUTH_API_SECRET"
+    twitter_bp.from_config["client_key"] = "TWITTER_OAUTH_CLIENT_KEY"
+    twitter_bp.from_config["client_secret"] = "TWITTER_OAUTH_CLIENT_SECRET"
 
     @twitter_bp.before_app_request
     def set_applocal_session():
